@@ -70,18 +70,24 @@ def eval_leaf(part, context, boolop=operator.and_):
             context_field = datetime.datetime.min
         else:
             context_field = datetime.date.min
+    if isinstance(context_field, (list, tuple)) and value is None:
+        value = type(context_field)()
     if (isinstance(context_field, basestring)
             and isinstance(value, (list, tuple))):
         try:
-            value = '%s,%s' % value
+            value = '%s,%s' % tuple(value)
         except TypeError:
             pass
     elif (isinstance(context_field, (list, tuple))
             and isinstance(value, basestring)):
         try:
-            context_field = '%s,%s' % context_field
+            context_field = '%s,%s' % tuple(context_field)
         except TypeError:
             pass
+    elif ((isinstance(context_field, list) and isinstance(value, tuple))
+            or (isinstance(context_field, tuple) and isinstance(value, list))):
+        context_field = list(context_field)
+        value = list(value)
     if (operand in ('=', '!=')
             and isinstance(context_field, (list, tuple))
             and isinstance(value, (int, long))):
@@ -584,6 +590,22 @@ def test_evaldomain():
     assert eval_domain(domain, {'x': [1, 2]})
     assert not eval_domain(domain, {'x': [2]})
 
+    domain = [['x', '=', None]]
+    assert eval_domain(domain, {'x': []})
+
+    domain = [['x', '=', ['foo', 1]]]
+    assert eval_domain(domain, {'x': 'foo,1'})
+    assert eval_domain(domain, {'x': ('foo', 1)})
+    assert eval_domain(domain, {'x': ['foo', 1]})
+    domain = [['x', '=', ('foo', 1)]]
+    assert eval_domain(domain, {'x': 'foo,1'})
+    assert eval_domain(domain, {'x': ('foo', 1)})
+    assert eval_domain(domain, {'x': ['foo', 1]})
+
+    domain = [['x', '=', 'foo,1']]
+    assert eval_domain(domain, {'x': ['foo', 1]})
+    assert eval_domain(domain, {'x': ('foo', 1)})
+
 
 def test_localize():
     domain = [['x', '=', 5]]
